@@ -46,14 +46,6 @@ static int8_t randomm_check_number (RandMem *rm_mem,
 static void randomm_set_number (RandMem *rm_mem,
                                 int32_t  i_no);
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Increment random number counts value
- *
- * @param[out] rm_mem  RandMem object
- * @return     none
- */
-static void randomm_increment_cnt (RandMem *rm_mem);
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Check if number is in random numbers memory
  */
@@ -88,15 +80,6 @@ randomm_set_number (RandMem *rm_mem,
     }
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Increment random number counts value
- */
-static void
-randomm_increment_cnt (RandMem *rm_mem)
-{
-    rm_mem->i_cnt++;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Clear / reset random memory.
  */
@@ -151,25 +134,6 @@ randomm_free (RandMem *rm_mem)
     free (rm_mem);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Set random numbers maximum range.
- */
-void
-randomm_set_range (RandMem *rm_mem,
-                   int32_t  i_rng)
-{
-    rm_mem->i_range = i_rng;
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Reset random number couts value
- */
-void
-randomm_reset_cnt (RandMem *rm_mem)
-{
-    rm_mem->i_cnt = 0;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get random number
  */
@@ -190,7 +154,7 @@ randomm_get_number (RandMem *rm_mem)
     /* set number in memory */
     randomm_set_number (rm_mem, ui_ret);
 
-    randomm_increment_cnt (rm_mem);
+    ++rm_mem->i_cnt;
 
     if (rm_mem->i_cnt >= rm_mem->i_range) {
         randomm_clear (rm_mem);
