@@ -19,7 +19,7 @@
  *
  * @brief  String operations 
  *
- * @author Michał Bąbik <michalb1981@o2.pl>
+ * @author Michal Babik <michal.babik@pm.me>
  */
 #include <stdlib.h>
 #include <stdio.h>
@@ -116,9 +116,6 @@ str_set_up_wallpaper_command (const char *s_cmd,
         s_res = str_replace_in (s_cmd, s_sign, s_fname);
     }
     str_append (&s_res, " &");
-    #ifdef DEBUG
-    printf ("%s\n", s_res);
-    #endif
     return s_res;
 }
 /*----------------------------------------------------------------------------*/
